==> avro-src-1.7.3.tar.gz: avro-src-1.7.3/lang/java/trevni/core/src/main/java/org/apache/trevni/ArrayColumnOutputBuffer.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.trevni;

import java.io.IOException;

/** A column output buffer for array columns. */
class ArrayColumnOutputBuffer extends ColumnOutputBuffer {
  private int length;                             // remaining in current array

  public ArrayColumnOutputBuffer(ColumnFileWriter writer, ColumnMetaData meta)
    throws IOException {
    super(writer, meta);
    assert getMeta().isArray() || getMeta().getParent() != null;
    assert !getMeta().hasIndexValues();
  }

  @Override public void writeLength(int length) throws IOException {
    assert this.length == 0;
    this.length = length;
    getBuffer().writeInt(length);
  }

  @Override public void writeValue(Object value) throws IOException {
    assert length > 0;
    getBuffer().writeValue(value, getMeta().getType());
    length -= 1;
  }

}

==> avro-src-1.7.4.tar.gz: avro-src-1.7.4/lang/java/trevni/core/src/main/java/org/apache/trevni/ArrayColumnOutputBuffer.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.trevni;

import java.io.IOException;

/** A column output buffer for array columns. */
class ArrayColumnOutputBuffer extends ColumnOutputBuffer {
  private int length;                             // remaining in current array

  public ArrayColumnOutputBuffer(ColumnFileWriter writer, ColumnMetaData meta)
    throws IOException {
    super(writer, meta);
    assert getMeta().isArray() || getMeta().getParent() != null;
    assert !getMeta().hasIndexValues();
  }

  @Override public void writeLength(int length) throws IOException {
    assert this.length == 0;
    this.length = length;
    getBuffer().writeLength(length);
  }

  @Override public void writeValue(Object value) throws IOException {
    assert length > 0;
    getBuffer().writeValue(value, getMeta().getType());
    length -= 1;
  }

}
